@@ -6,7 +6,7 @@
 # description: Packet filtering firewall
 
 ### BEGIN INIT INFO
-# Provides: shorewall
+# Provides: shorewall6
 # Required-Start: $local_fs $remote_fs $syslog $network
 # Should-Start: VMware $time $named
 # Required-Stop:
@@ -20,31 +20,26 @@
 # Source function library.
 . /etc/rc.d/init.d/functions
 
-#
-# The installer may alter this
-#
-. /usr/share/shorewall/shorewallrc
-
-prog="shorewall"
-shorewall="${SBINDIR}/$prog"
+prog="shorewall6"
+shorewall="/sbin/$prog"
 logger="logger -i -t $prog"
 lockfile="/var/lock/subsys/$prog"
 
 # Get startup options (override default)
 OPTIONS=
 
-if [ -f ${SYSCONFDIR}/$prog ]; then
-    . ${SYSCONFDIR}/$prog
+if [ -f /etc/sysconfig/$prog ]; then
+    . /etc/sysconfig/$prog
 fi
 
 start() {
-    printf $"Starting Shorewall: "
-    $shorewall $OPTIONS start $STARTOPTIONS 2>&1 | $logger
+    echo -n $"Starting Shorewall: "
+    $shorewall $OPTIONS start 2>&1 | $logger
     retval=${PIPESTATUS[0]}
-    if [[ $retval == 0 ]]; then
+    if [[ $retval == 0 ]]; then 
 	touch $lockfile
 	success
-    else
+    else 
 	failure
     fi
     echo
@@ -52,28 +47,13 @@ start() {
 }
 
 stop() {
-    printf $"Stopping Shorewall: "
+    echo -n $"Stopping Shorewall: "
     $shorewall $OPTIONS stop 2>&1 | $logger
     retval=${PIPESTATUS[0]}
-    if [[ $retval == 0 ]]; then
+    if [[ $retval == 0 ]]; then 
 	rm -f $lockfile
 	success
-    else
-	failure
-    fi
-    echo
-    return $retval
-}
-
-reload() {
-    printf $"Reloading Shorewall: "
-    $shorewall $OPTIONS reload $RELOADOPTIONS 2>&1 | $logger
-    retval=${PIPESTATUS[0]}
-    if [[ $retval == 0 ]]; then
-	touch $lockfile
-	success
-    else # Failed to start, clean up lock file if present
-	rm -f $lockfile
+    else 
 	failure
     fi
     echo
@@ -83,10 +63,10 @@ reload() {
 restart() {
 # Note that we don't simply stop and start since shorewall has a built in
 # restart which stops the firewall if running and then starts it.
-    printf $"Restarting Shorewall: "
-    $shorewall $OPTIONS restart $RESTARTOPTIONS 2>&1 | $logger
+    echo -n $"Restarting Shorewall: "
+    $shorewall $OPTIONS restart 2>&1 | $logger
     retval=${PIPESTATUS[0]}
-    if [[ $retval == 0 ]]; then
+    if [[ $retval == 0 ]]; then 
 	touch $lockfile
 	success
     else # Failed to start, clean up lock file if present
@@ -115,10 +95,7 @@ case "$1" in
 	status_q || exit 0
 	$1
 	;;
-    reload|force-reload)
-	reload
-	;;
-    restart)
+    restart|reload|force-reload)
 	restart
 	;;
     condrestart|try-restart)
